<?php
namespace net\xmp\phpbuch;

class DatabaseConnection
{
    public $handle = null;

    protected $serverName = '(local)';
    protected $connectionInfo = array(
                        'Database' => 'AdventureWorksLT2008',
                        'CharacterSet' => 'UTF-8');

    /**
     * Verbindung mit SQL Server herstellen.
     * Es werden vordefinierte Verbindungsparameter verwendet.
     */
    function connect()
    {
        $this->handle = sqlsrv_connect($this->serverName, $this->connectionInfo);
        if ($this->handle === false) {
            $this->exitWithError('Datenbankverbindung fehlgeschlagen');
        }
    }

    /**
     * Verbindung zu SQL Server schließen.
     */
    function close()
    {
        if ($this->handle) {
            sqlsrv_close($this->handle);
            $this->handle = null;
        }
    }
    
    /**
     * Programm beenden, Fehlermeldung von SQL Server ausgeben
     * 
     * @param string $txt Beschreibung des Fehlerkontexts
     */
    function exitWithError($txt)
    {
        $errors = sqlsrv_errors();
        $html = new HTMLPage('Datenbankfehler');
        $html->addElement('p', $txt);
        $table = array( array('SQL-Status', 'Code', 'Meldung') );
        foreach ($errors as $error) {
            // Fehlermeldungen werden im ISO-8859-1-Format übertragen
            $msg = iconv('ISO-8859-1', 'UTF-8', $error['message']);
            $table[] = array($error['SQLSTATE'], $error['code'], $msg);
        }
        $html->addTable($table);
        $html->printPage();
        $this->close();
        exit;
    }
}
?>
