<?php
namespace net\xmp\phpbuch;
class UpdateOrders
{
    protected $db;
    protected $stmt;
    
    // An Anweisung gebundene Variablen
    protected $sql_qty, $sql_discount, $sql_id;
    
    /**
     * Konstruktor setzt Datenbankverbindung
     */
    function __construct($db)
    {
        $this->db = $db;
    }

    /**
     * Relevanten Daten aus Tabelle auslesen und in HTML-Array schreiben.
     * @param int $id Nummer des SalesOrder
     */
    function getByHeader($id)
    {
        $query = 'SELECT SalesOrderDetailID, OrderQty, UnitPriceDiscount
                  FROM SalesLT.SalesOrderDetail WHERE SalesOrderID = ?';
        $params = array($id);
        $stmt = sqlsrv_query($this->db->handle, $query, $params);
        if ($stmt === false) {
            $this->db->exitWithError('Abfrage der Daten fehlgeschlagen.');
        }
        // Einzelne Zeilen des Ergebnisses auslesen
        $table = array( array('ID', 'Menge', 'Rabatt') );
        while ($row = sqlsrv_fetch_array($stmt)) {
            $table[] = array($row['SalesOrderDetailID'], $row['OrderQty'],
                             $row['UnitPriceDiscount']);
        }
        if ($row === false) {
            $this->db->exitWithError('Abfruf der Daten fehlgeschlagen.');
        }
        sqlsrv_free_stmt($stmt);
        return $table;
    }
    
    /**
     * Vorbereiten der Aktualisierungsanweisung.
     */
    function prepare()
    {
        $query = 'UPDATE SalesLT.SalesOrderDetail
                  SET OrderQty = ?, UnitPriceDiscount = ?
                  WHERE SalesOrderDetailID = ?';
        // Parameter müssen als Verweise (&$...) verwendet werden.
        // Dadurch übertragen sich alle späteren Änderungen der Variablen
        // in die vorbereitete TSQL-Anweisung
        $params = array(&$this->sql_qty, &$this->sql_discount, &$this->sql_id);
        // Anweisung vorbereiten
        $this->stmt = sqlsrv_prepare($this->db->handle, $query, $params);
        if ($this->stmt === false) {
            $this->db->exitWithError("Anweisungsvorbereitung fehlgeschlagen.");
        }
    }
    /**
     * Vorbereitete Anweisung ausführen.
     * Als Parameter werden die zu aktualisierenden Werte übergeben.
     */
    function update($id, $qty, $discount)
    {
        // Aktualisierung der Variablen überträgt sich auf TSQL-Anweisung,
        // da Variablen als Verweise gebunden worden sind.
        $this->sql_id = $id;
        $this->sql_qty = $qty;
        $this->sql_discount = $discount;
        if (sqlsrv_execute($this->stmt) === false) {
            $this->db->exitWithError('Aktualisierung fehlgeschlagen.');
        }
    }

    function free()
    {
        sqlsrv_free_stmt($this->stmt);
    }
}
?>
