/* getCreditPrice:
 * Berechnet Produktpreis, wenn auf Kredit gekauft wird
 */
CREATE PROC SalesLT.getCreditPrice
  @id int,                          -- SalesLT.Product.ProductId
  @rate real,                       -- monatlicher Zinssatz
  @months int = 12,                 -- Anzahl der Monate
  @listPrice money OUTPUT,
  @price money OUTPUT
AS
  DECLARE @fee money;               -- Definition einer lokalen Variable für Gebühren
  SET @price = (
    SELECT ListPrice FROM SalesLT.Product 
    WHERE ProductID = @id);
  SET @listPrice = @price;
  SET @fee = CASE                   -- Gebühren sind abhängig von Produktpreis
    WHEN @price < 10.0 THEN 0.50
    WHEN @price < 50.0 THEN 1.00
    ELSE                    2.00
  END;
  IF (@months >= 24) BEGIN          -- Laufzeit länger als 2 Jahre, dann doppelte Gebühr
    SET @fee *= 2;
  END
  WHILE (@months > 0) BEGIN         -- Berechnen der Zins und Zinseszinsen
    SET @price = @price * (1+@rate);
    SET @months -= 1;
  END
  SET @price += @fee;
GO
