<?php
namespace net\xmp\phpbuch;

class LDAPConnection
{
    public $handle = null;

    /**
     * Verbindung mit LDAP-Verzeichnis herstellen.
     *
     * @param string $server Name des LDAP-Servers
     * @param string $username Benutzername
     * @param string $password Passwort
     * @param boolean $secure Gibt an, ob eine TLS-verschlüsselte Verbindung verwendet werden soll
     */
    function connect($server, $userName, $password, $secure=false)
    {
        $this->handle = ldap_connect($server);
        ldap_set_option($this->handle, LDAP_OPT_PROTOCOL_VERSION, 3);
        ldap_set_option($this->handle, LDAP_OPT_REFERRALS, 0);
        if ($secure) {
            if (!ldap_start_tls($this->handle)) {
                $this->exitWithError('Start-TLS fehlgeschlagen');
            }
        }
        if (!ldap_bind($this->handle, $userName, $password)) {
            $this->exitWithError('Bindung der LDAP-Verbindung fehlgeschlagen');
        }
    }

    /**
     * Verbindung zu LDAP-Verzeichnis schließen.
     */
    function close()
    {
        if ($this->handle) {
            ldap_unbind($this->handle);
            $this->handle = null;
        }
    }
    
    /**
     * Programm beenden, Fehlermeldung von LDAP-Verzeichnis ausgeben
     * 
     * @param string $txt Beschreibung des Fehlerkontexts
     */
    function exitWithError($txt)
    {
        $errors = ldap_error();
        $html = new HTMLPage('LDAP-Fehler');
        $html->addElement('p', $txt);
        $table = array( array('Nummer', 'Meldung'),
                        array(ldap_errno($this->handle), ldap_error($this->handle)));
        $html->addTable($table);
        $html->printPage();
        $this->close();
        exit;
    }
}
?>
