// Exception-Klasse
class LDAPException extends Exception { }

/**
 * Authentifizieren eines Benutzers gegen Active Directory
 * @param string $server Name des Servers
 * @param string $username Benutzername
 * @param string $password Kenntwort
 * @param boolean $secure Gibt an, ob eine verschlüsselte Verbindung aufgebaut werden soll
 * @return boolean true bei Erfolg, false bei Misserfolg
 * @throws LDAPConnectionException
 */
function authenticate($server, $username, $password, $secure=true)
{
    $handle = ldap_connect($server);
    if ($secure) {
        if (!ldap_start_tls($handle)) {
            return -1;
        }
    }
    if (!ldap_bind($handle, $username, $password)) {
        $code = ldap_errno($handle);
        ldap_unbind($handle);
        if ($code != 49) {
            throw new LDAPException('LDAP-Verbindungsfehler');
        }
        return false;
    }
    ldap_unbind($handle);
    return true;
}
