<?php
/* Vollständig zusammengesetztes Listing */
namespace net\xmp\phpbuch;

require './HTMLPage.php';
require './LDAPConnection.php';
require './LDAPEntryFormatter.php';
require './browse_ldap_types.php';
require './AD_util.php';

$html = new HTMLPage('LDAP-Browser');
$form = <<<EOF
<form action="" method="get">
Name: <input name="name" />
<select name="type">
EOF;
foreach ($objectClasses as $name => $config) {
    $form .= sprintf('<option value="%s">%s</option>', htmlspecialchars($name),
                                                       htmlspecialchars($config['name']));
}
$form .= <<<EOF
</select>
<input type="submit" value="Suchen" />
</form><br />
EOF;
$html->addHTML($form);
// Prüfen, ob Parameter vorhanden sind
if (!isset($_GET['name']) || !isset($_GET['type'])) {
    $html->printPage();
    exit;
}
// Verbindung herstellen
$ad = new LDAPConnection();
$ad->connect('dc.xmp.site', 'arno@xmp.site', 'streng-geheim');
// Parameter filtern
if (!isset($objectClasses[$_GET['type']])) {
    $ad->exitWithError('Falscher Eintragstyp!');
}
$class = $objectClasses[$_GET['type']];

// Zwei unterschiedliche Sucharten: Objekt nach DN suchen ...
if (isset($_GET['getDN'])) {
    $result = ldap_read($ad->handle, $_GET['name'],
                        '(objectClass=*)',$class['attributes']);
}
// ... oder ausgehend von baseDN mit Filter suchen
else {
    $name = preg_replace($class['filterchars'], '', $_GET['name']);
    $filter = sprintf($class['filter'], $name);
    $result = ldap_search($ad->handle, $class['baseDN'],
                          $filter, $class['attributes']);
}
if (!$result) {
    $ad->exitWithError('LDAP-Suche fehlgeschlagen.');
}

// Abhängig von Anzahl der Treffer unterschiedliche Anzeige
$cnt = ldap_count_entries($ad->handle, $result);
if (!$cnt) {
    $html->addElement('p', 'Keine Treffer gefunden.');
}
elseif ($cnt == 1) {
    list($heading, $table) = listSingleEntry($ad, $result, $_GET['type']);
    $html->addElement('h2', $heading);
    $html->addTable($table, array(true, true));
}
else {
    $list = listEntries($ad, $result, $_GET['type']);
    $html->addElement('h2', 'Suchergebnis');
    $html->addList($list, true);
}
// Resultat freigeben, Verbindung schließen
ldap_free_result($result);
$ad->close();
$html->printPage();


/**
 * Liest mehrere Suchtreffer aus und listet sie in kurzer Form auf
 */
function listEntries($ad, $result, $class)
{
    $entries = ldap_get_entries($ad->handle, $result);
    if (!$entries) {
        $ad->exitWithError('Lesen der LDAP-Suchergebnisse fehlgeschlagen.');
    }
    $list = array();
    for($i=0; $i < $entries['count']; $i++) {
    
        $list[] = '<a href="browse_ldap.php?name=' . rawurlencode($entries[$i]['dn'])
                . '&amp;type=' . rawurlencode($class)
                . '&amp;getDN=1">' . htmlspecialchars($entries[$i]['dn']) . '</a>';
    }
    return $list;
}

/**
 * Liest einen einzelnen Suchtreffer aus und 
 * formatiert ihn für die Ausgabe
 */
function listSingleEntry($ad, $result, $class)
{
    $entry = ldap_first_entry($ad->handle, $result);
    if (!$entry) {
        $ad->exitWithError('Lesen des LDAP-Eintrages fehlgeschlagen.');
    }
    $attr = ldap_get_attributes($ad->handle, $entry);
    $ef = new LDAPEntryFormatter($attr, $class, 'browse_ldap.php');
    $table = $ef->getAttributes();
    $title = $class . ': ' . ldap_get_dn($ad->handle, $entry);
    return array($title, $table);
}
?>
