<?php
/* Vollständig zusammengesetztes Listing */
namespace net\xmp\phpbuch;

$rootDN = 'DC=xmp,DC=site';

/**
 * Definition der Suchen und Objektklassen
 */
$objectClasses = array(
    'classSchema' => array(
        'name' => 'Schema: Objektklasse',
        'baseDN' => "CN=Schema,CN=Configuration,$rootDN",
        'filter' => '(&(lDAPDisplayName=%s)(objectClass=classSchema))',
        'attributes' => array(
            'name', 'lDAPDisplayName', 'subClassOf', 'defaultObjectCategory',
            'objectCategory', 'systemPossSuperiors', 'possSuperiors', 
            'auxiliaryClass', 'systemAuxiliaryClass', 'mustContain', 
            'systemMustContain', 'mayContain', 'systemMayContain',
            'systemOnly', 'possibleInferiors', 'defaultHidingValue',
            'adminDescription')
    ),
    'attributeSchema' => array(
        'name' => 'Schema: Attributklasse',
        'baseDN' => "CN=Schema,CN=Configuration,$rootDN",
        'filter' => '(&(lDAPDisplayName=%s)(objectClass=attributeSchema))',
        'attributes' => array(
            'name', 'lDAPDisplayName', 'objectCategory', 'isSingleValued',
            'attributeID', 'attributeSyntax', 'oMSyntax', 'systemOnly',
            'isMemberOfPartialAttributeSet','systemFlags', 'searchFlags',
            'adminDescription')
    ),
    'object' => array(
        'name' => 'Frei definierbarer Filter',
        'baseDN' => $rootDN,
        'filter' => '%s',
        'filterchars' => '/\x00/',
        'attributes' => array()
    ),
    'user' => array(
        'name' => 'Benutzer',
        'baseDN' => $rootDN,
        'filter' => '(&(objectClass=User)(objectCategory=Person)(name=%s))',
        'attributes' => array(
            'name', 'displayName', 'userPrincipalName', 'memberOf', 'lastLogon',
            'userAccountControl', 'accountExpires', 'objectCategory',
            'objectClass', 'objectGUID', 'objectSid')
    ),
    'group' => array(
        'name' => 'Gruppe',
        'baseDN' => $rootDN,
        'filter' => '(&(objectCategory=Group)(name=%s))',
        'attributes' => array(
            'name', 'sAMAccountName', 'member', 'memberOf', 'objectCategory',
            'objectClass', 'groupType', 'objectGUID', 'objectSid', 'mail')
    ),
    'organizationalUnit' => array(
        'name' => 'Organisationseinheit',
        'baseDN' => $rootDN,
        'filter' => '(&(objectClass=organizationalUnit)(ou=%s))',
        'attributes' => array(
            'ou', 'name', 'description', 'objectCategory', 
            'objectClass', 'objectGUID')
    ),
);

// Standardwerte setzen
foreach ($objectClasses as &$oc) {
    if (isset($oc['base'])) {   // Kopieren von anderer Definition
        foreach ($objectClasses[$oc['base']] as $name => $val) {
            if (!isset($oc[$name])) {
                $oc[$name] = $val;
            }
        }
    }
    if (!isset($oc['filterchars'])) {
        $oc['filterchars'] = "/[^-_ a-z0-9*.']/i";
    }
}

/**
 * Verlinken und Konvertieren von Attributen
 */
$attributeConvertion = array(
    'subClassOf' => 'classSchema',
    'possSuperiors' => 'classSchema',
    'systemPossSuperiors' => 'classSchema',
    'possibleInferiors' => 'classSchema',
    'auxiliaryClass' => 'classSchema',
    'systemAuxiliaryClass' => 'classSchema',
    'mustContain' => 'attributeSchema',
    'systemMustContain' => 'attributeSchema',
    'mayContain' => 'attributeSchema',
    'systemMayContain' => 'attributeSchema',
    'attributeSyntax' => 'oidInfo',
    'objectCategory' => 'DN-classSchema',
    'objectClass' => 'classSchema',
    'objectGUID' => 'guid2str',
    'systemFlags' => 'dec2hex',
    'instanceType' => 'dec2hex',
    'lastLogon' => 'winStamp2str',
    'lastLogonTimestamp' => 'winStamp2str',
    'badPasswordTime' => 'winStamp2str',
    'userAccountControl' => 'accountControl2str',
    'accountExpires' => 'winStamp2str',
    'objectSid' => 'sid2str',
    'memberOf' => 'DN-group',
    'member' => 'DN-object',
    'groupType' => 'groupType2Str',
);
?>
