class LDAPConnection
{
    // ...
    public $baseDN = '';

    // ...

    /**
     * Auslesen eines Eintrages mit SAM-Accountname
     * @param string $account SAM-Accountname
     * @param array $attributes auszulesende Attribute
     * @param string $baseDN Basis-DN für Suche
     */
    function getAccount($account, $attributes=array(), $baseDN='')
    {
        $filter = '(sAMAccountName=' . escapeLDAP($account) . ')';
        $account = $this->getOneEntry($filter, $attributes, $baseDN);
        if (!$account) {
            $this->exitWithError('Account nicht gefunden.');
        }
        return $account;
    }

    /**
     * Auslesen eines Eintrages einer Suche
     * @param string $filter Filterzeichenfolge
     * @param array $attributes auszulesende Attribute
     * @param string $baseDN Basis-DN für Suche
     */
    function getOneEntry($filter, $attributes=array(), $baseDN='')
    {
        if (empty($baseDN)) {
            $baseDN = $this->baseDN;
        }
        $result = ldap_search($this->handle, $baseDN, $filter, $attributes);
        if (!$result) {
            return false;
        }
        $entry = ldap_first_entry($this->handle, $result);
        if (!$entry) {
            return false;
        }
        $attr = ldap_get_attributes($this->handle, $entry);
        if (!$attr) {
            return false;
        }
        $attr['dn'] = ldap_get_dn($this->handle, $entry);
        return $attr;
    }
}
